Anzeige: Value-Stars: Mit ausgewählten Aktien den DAX schlagen | Nachricht | finanzen.net
Description: Mit der Anlagestrategie von Warren Buffet hat der Value-Stars-Deutschland-Index den DAX deutlich abgehängt. So profitieren auch Sie von dieser Strategie! 17.09.2021

DAX: 15.490 -1,0%ESt50: 4.131 -0,9%TDax: 3.883 -0,5%Dow: 34.585 -0,5%Nas: 15.044 -0,9%Bitcoin: 40.032 -1,5%Euro: 1,1737 -0,3%Öl: 75,32 -0,5%Gold: 1.754 +0,1%

- Suche

Beliebte Suchen
DAX 30

Öl

Euro US-Dollar

Bitcoin

Goldpreis

Meistgesucht
BioNTech (ADRs)

NEL ASA

Lilium

BVB (Borussia Dortmund)

CureVac

Bayer

Continental AG

Vitesco Technologies

Commerzbank

Valneva

BASF

BYD Co. Ltd.

Varta AG

Apple Inc.

InnoCan Pharma Corporation Registered Shs

17.09.2021 18:17
Werbemitteilung unseres Partners

# Value-Stars: Mit ausgewählten Aktien den DAX schlagen

Anzeige
Folgen
FACEBOOK
DRUCKEN
Mit der Anlagestrategie von Warren Buffet hat der Value-Stars-Deutschland-Index den DAX deutlich abgehängt. So profitieren auch Sie von dieser Strategie!
Werbung

### Indizes in diesem Artikel

Value-Stars-Deutschland-Index
340,5
0,4%
Aktien in diesem Artikel anzeigen
Value-Stars-Deutschland-Index
340,5 0,4%
Alle anzeigen

Die höchsten Renditen erzielen Anleger nicht zwangsläufig mit Aktien großer Unternehmen. Wer systematisch in solide Aktien aus dem deutschen Nebenwertesegment investiert, kann damit eine außergewöhnliche Performance erzielen. Das beweist der aktiv gemanagte Value-Stars-Deutschland-Index, der seit der Auflage am 23. Dezember 2013 eine beachtliche Rendite von 225,6 % erzielt hat (Stand: 31.07.2021). Zum Vergleich: Der deutschen Leitindex DAX hat im selben Zeitraum nur um 64,7 % zugelegt.

## Entwicklung seit Auflage in der Übersicht

Die nachstehende Tabelle verdeutlicht den langjährigen Erfolg dieser Strategie. Seit Auflage am 23.12.2013 hat der Index um 225,6 % zugelegt (Stand: 31.07.2021). Das entspricht einer durchschnittlichen Entwicklung von 16,8 % pro Jahr.

## Die Erfolgsformel des Value-Stars-Deutschland-Index

Das Erfolgsrezept hinter dieser Entwicklung ist die bewährte und langjährig erfolgreiche Value-Investing-Strategie des Börsenbriefs "Der Anlegerbrief". Seit dem Jahr 1999 erwirtschaftet der Anlegerbrief mit seinem Musterdepot eine Rendite von im Schnitt rund 17,3 % pro Jahr. Mit einer Value-Strategie, die sich an den Grundsätzen erfolgreicher Investoren wie Warren Buffett oder Benjamin Graham orientiert.

Im Vordergrund stehen dabei rein fundamentale Kriterien, z. B. die wirtschaftliche Verfassung und Wettbewerbsposition eines Unternehmens. Aber auch die Qualität des Managements sowie der innere Wert einer Aktie spielen eine besondere Rolle. "Der innere Wert soll dabei deutlich über dem Kurswert liegen", so Holger Steffen, der Chefanalyst des Anlegerbriefs. "Vereinfacht gesagt folgen wir der Faustformel, dass wir Aktien dann kaufen, wenn Sie zum halben inneren Wert zu haben sind. Entsprechend investieren wir in Aktien mit dem Potenzial, sich zu verdoppeln."

Anleger können ganz einfach an dem Value-Stars-Deutschland-Index partizipieren. Sie können das Investment-Zertifikat auf diesen Index unter der WKN LS8VSD jederzeit wie eine Aktie über die Börse Stuttgart oder im Direkthandel mit Lang & Schwarz kaufen und verkaufen.

## Weitere Informationen

Weitere Informationen finden Sie auf der Website zum Value-Stars-Deutschland-Zertifikat.

Wichtige Hinweise:
Dieser Text richtet sich nur an Anleger mit dauerhaftem Wohnsitz in Deutschland. Er dient ausschließlich zu Informationszwecken und stellt weder ein Angebot noch eine Beratung, Empfehlung oder Aufforderung zum Kauf oder Verkauf des dargestellten Zertifikats dar. Den oben genannten Chancen stehen naturgemäß auch Risiken gegenüber, insbesondere das Ausfallrisiko des Emittenten und das Kursrisiko des Zertifikats bei negativer Entwicklung der im Index enthaltenen Aktien. Zudem stellen weder die historischen Renditen des Zertifikats noch des Musterdepots des Anlegerbriefs eine Garantie für zukünftige Erträge dar.

Es wird dringend empfohlen, dass Anleger vor einer Investition den Rat eines qualifizierten Finanzberaters einholen. Eine Anlageentscheidung sollte nur auf der Grundlage der Informationen und insbesondere der Risikohinweise in den prospektrechtlichen Dokumenten der Lang & Schwarz Aktiengesellschaft (Endgültige Bedingungen, Basisprospekt nebst Nachträgen auf www.ls-tc.de) erfolgen.

## Weitere News zum Thema

- Der Value-Stars-Deutschland-Index im Überblick
- Investieren in Small Caps - chancenreiche Nebenwerte-Fonds und -Investments
- Value-Stars-Newsletter

Bildquellen: ESB Professional / Shutterstock.com
FACEBOOK
zur Startseite

## Newssuche

GO
Werbung

## Heute im Fokus

DAX geht unter 15.500 Punkten ins Wochenende -- US-Börsen schließen schwächer -- Cerberus: Interesse an Commerzbank-Staatsanteil -- Vonovia, Deutsche Wohnen, Biotest im Fokus

Drägerwerk: Aussicht auf höhere Dividende. Weiter verschärft: Daimler Truck leidet unter Halbleiter-Engpässen. Tesla-Chef Musk kommt zum Tag der offenen Tür nach Deutschland. Deutsche Bank-Aktie: Sewing entschuldigt sich für scharfe Kritik in Analysten-Studie. HOCHTIEF-Tochter CIMIC erhält Auftrag für Western Sydney Airport. Stimmung der US-Verbraucher hellt sich im September auf. E.ON-Chef setzt auf Netze als Treiber der Energiewende.

## MEISTGELESENE ARTIKEL

Conti-Aktie im Minus, Vitesco-Titel tiefer: Continental spaltet Vitesco ab
Commerzbank-Aktie schließt höher: Cerberus zeigt offenbar Interesse an Commerzbank-Staatsanteil - Bank setzt mehr auf Klimaschutz
Gold fällt auf den niedrigsten Stand seit Mitte August
Bitcoin-Miner verlassen China - und ziehen ins neue Krypto-Eldorado
BVB-Aktie bricht zweistellig ein: Borussia Dortmund stößt Kapitalerhöhung an

Werbung

### Trading-News

| DZ BANK - Brenntag: Akquisitionen sind Teil der Wachstumsformel
| Der DAX 40 wird (fast) wie der DAX 30 laufen – Lesen Sie hier warum und wo Experten das Kursziel bis zum Ende des Jahres sehen
| Chevron will „grünes“ Geschäft deutlich ausbauen
| Vontobel: Interview: In Krypto investieren – aber nicht in die Währungen

Alle Trading-News
Werbung

### Investment-News

| Der "beste Robo Advisor 2021" im Web Seminar
| Keine Angst vor der Wahl
| Schwerpunkt der Woche: Rendite durch Zocker
| Für Fintech steht ein goldenes Jahrzehnt an
| Baker Steel: Gute Voraussetzungen für höhere Silberpreise
| Die Renteninformation - Alles was Sie wissen müssen
| OSKAR ETF-Sparplan kostenlos testen
| JETZT NEU: Aktienhandel für 0 Euro bei finanzen.net zero - jetzt informieren

Alle Investment-News
Alle News auch auf XING
Die wichtigsten News von finanzen.net auf XING lesen - so einfach geht's
Werbung
Werbung

## Top-Rankings

| MDAX: Die Gewinner und Verlierer in KW 37 2021 Welche Aktie macht das Rennen? Jetzt durchklicken
| TecDAX: Die Gewinner und Verlierer in KW 37 2021 Welche Aktie macht das Rennen? Jetzt durchklicken
| DAX 30: Die Gewinner und Verlierer in KW 37 2021 Welche Aktie macht das Rennen? Jetzt durchklicken

## Umfrage

Wenn morgen Bundestagswahl wäre, wen würden Sie wählen?

SPD
CDU / CSU
Grüne
FDP
Andere
Abstimmen
Direkt zu den Ergebnissen

###
News von

Valneva mit Kurseinbruch - Großbritannien storniert Vertrag
Robuste Riesen: Diese Aktien machen Ihr Depot krisenfest
DAX ein Prozent im Plus - Anleger in Europa zum Wochenstart wieder zuversichtlicher
Vitesco-Börsengang lohnt sich für Conti-Aktionäre nicht
Siemens-Aktie, Bechtle und Hornbach: Drei DAX-Vertreter mit Kursrekorden im Anlage-Check

###
News von

„Wir brauchen nach der Wahl einen Plan für den Ausstieg des Staates“
„Finaltag“ – Das große Umschichten beendet eine goldene Ära
„Wir in Europa könnten das durchaus noch vor uns haben“
Berliner Senat schließt Deal mit Deutsche Wohnen und Vonovia
Diese Faktoren bestimmen den Wert Ihrer Immobilie

JETZT INFORMIEREN

ETF-Sparplan

Oskar ist der einfache und intelligente ETF-Sparplan. Er übernimmt die ETF-Auswahl, ist steuersmart, transparent und kostengünstig.
JETZT MEHR ERFAHREN
Zur klassischen Ansicht wechseln
Hilfe & Kontakt
Impressum
Werben
Presse
mehr anzeigen